# Changelog

- This file provides a full account of all changes to `dbt-tests-adapter`
- The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
and is generated by [Changie](https://github.com/miniscruff/changie)
- Changes are listed under the (pre-)release in which they first appear
- Subsequent releases include changes from previous releases
- "Breaking changes" listed under a version may require action from end users or external maintainers when upgrading to that version
- Do not edit this file directly. This file is auto-generated using [changie](https://github.com/miniscruff/changie)
- For details on how to document a change, see the [contributing guide](/CONTRIBUTING.md#changelog-entry)

## dbt-tests-adapter 1.19.2 - November 04, 2025

### Features

- Add tests for the setting of volatility for sql UDFs ([#1345](https://github.com/dbt-labs/dbt-adapters/issues/1345))
- Create base test for unknown function macro lookup ([#1344](https://github.com/dbt-labs/dbt-adapters/issues/1344))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))



## dbt-tests-adapter 1.19.1 - October 02, 2025

### Features

- Add new test base for UDFs ([#1268](https://github.com/dbt-labs/dbt-adapters/issues/1268))

### Fixes

- Fix duplicates when hard_deletes new_record is used with custom dbt_valid_to_current ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))
- Fix file fixtures for functions to use proper function property names ([#1365](https://github.com/dbt-labs/dbt-adapters/issues/1365))

### Contributors
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))

## dbt-tests-adapter 1.18.0 - August 19, 2025

### Features

- Add new test for test unit tests involing models with columns with reserved words ([#1273](https://github.com/dbt-labs/dbt-adapters/issues/1273))

## dbt-tests-adapter 1.17.0 - July 29, 2025

### Features

- Add test for scenario where soure/target relations are the same ([#1198](https://github.com/dbt-labs/dbt-adapters/issues/1198))
- Add BaseSnapshotEphemeralHardDeletes test  ([#1201](https://github.com/dbt-labs/dbt-adapters/issues/1201))

### Fixes

- Fix test suite simple_snapshot/test_various_configs import path ([#972](https://github.com/dbt-labs/dbt-adapters/issues/972))

### Under the Hood

- Improve test coverage for snapshots with new record mode ([#654](https://github.com/dbt-labs/dbt-adapters/issues/654))

### Contributors
- [@99Lys](https://github.com/99Lys) ([#972](https://github.com/dbt-labs/dbt-adapters/issues/972))
- [@lpillmann](https://github.com/lpillmann) ([#654](https://github.com/dbt-labs/dbt-adapters/issues/654))

## dbt-tests-adapter 1.16.0 - June 04, 2025

### Features

- Add BaseCatalogIntegrationValidation to support catalog integration testing ([#1134](https://github.com/dbt-labs/dbt-adapters/issues/1134))

## dbt-tests-adapter 1.15.1 - May 28, 2025

### Fixes

- Modify tests to exercise case differences in snapshot target meta columns. ([#1101](https://github.com/dbt-labs/dbt-adapters/issues/1101))

### Under the Hood

- Add new tests for snapshots in new_record mode in combination with check columns. ([#1068](https://github.com/dbt-labs/dbt-adapters/issues/1068))

## dbt-tests-adapter 1.15.0 - May 02, 2025

### Features

- Add base test case for sample mode ([#878](https://github.com/dbt-labs/dbt-adapters/issues/878))
- Add tests for `empty` and `sample` modes against python models ([#906](https://github.com/dbt-labs/dbt-adapters/issues/906))

### Fixes

- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))

## dbt-tests-adapter 1.11.0 - February 07, 2025
